@@ -1,4 +1,7 @@
-from . import middleware
+from .middleware import django
+from .middleware import aiohttp
+from .middleware import celery
+from .middleware import flask
 from .notifier import Notifier
 from .logging import LoggingHandler
 from .version import version as __version__
